Certificati | OiRA
Description: A seconda dell’approccio adottato dal partner OiRA/dallo sviluppatore dello strumento nazionale, può essere possibile ottenere un certificato per la tua valutazione dei rischi. Per informazioni dettagliate sui vantaggi di tali certificati contatta il tuo partner OiRA nazionale.

Temi

# Certificati

A seconda dell’approccio adottato dal partner OiRA/dallo sviluppatore dello strumento nazionale, può essere possibile ottenere un certificato per la tua valutazione dei rischi. Per informazioni dettagliate sui vantaggi di tali certificati contatta il tuo partner OiRA nazionale.

Come ottenere un certificato

## Eseguire una valutazione dei rischi completa

OiRA registra i tuoi progressi nell’esecuzione della valutazione dei rischi. Dopo che avrai valutato una serie di rischi, lo strumento ti comunicherà la possibilità di ottenere un certificato una volta ultimata la valutazione dei rischi completa. Ciascun partner OiRA/sviluppatore dello strumento nazionale fissa la soglia (percentuali) richiesta per poter definire «completa» una valutazione dei rischi. Il certificato è accessibile mediante il pulsante «Stato» nel menù sul lato sinistro della schermata.

La pagina dello stato mostra che è disponibile un certificato.

## Visualizzare e pubblicare il certificato

Quando fai clic sul pulsante «Visualizza certificato» ti verrà chiesto di inserire la ragione o denominazione sociale dell’impresa che dovrebbe figurare sul certificato. A seconda delle impostazioni nazionali, ti può essere chiesto di inserire ulteriori dati per garantire che il certificato contenga tutte le informazioni che devi fornire.

Inserire tutte le informazioni richieste per il certificato.

Spuntando il riquadro denominato «Rendi pubblico» comparirà un link univoco (URL) al tuo certificato. Copia il link e condividilo con le persone interessate, per dimostrare che hai eseguito la valutazione dei rischi.

Nota: saranno resi pubblici soltanto i dati visualizzati su questa pagina. Questo link non è accessibile attraverso il menù del sito web OiRA, perché è specifico per te. Tuttavia, chiunque navighi in Internet potrebbe teoricamente visualizzare il certificato che hai creato!

Il certificato attesta soltanto che hai risposto a un certo numero di rischi nello strumento di valutazione dei rischi, ma non fornisce nessun’altra informazione. Le risposte specifiche alla valutazione dei rischi che hai dato completando lo strumento OiRA possono essere visualizzate soltanto da te e da nessun altro.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More